SCA61T Single Axis Inclinometer

Dependents:   SCA61T_example

Revision:
2:b0d8ca64cb0f
Parent:
1:663ebf72b607
--- a/SCA61T.h	Thu Feb 24 10:36:11 2011 +0000
+++ b/SCA61T.h	Thu Mar 10 16:07:16 2011 +0000
@@ -33,7 +33,7 @@
 * #include "mbed.h"
 * #include "SCA61T.h"
 *
 * SCA61T sca61t(p11,p12,p13,p21,0);                  // MOSI, MISO, SCLK, CBS, device selection
 *                                                    // 0=SCA61T-FAHH1G, 1=SCA61T-FA1H1G 
 * Serial pc(USBTX, USBRX);
 *
@@ -51,7 +51,7 @@
 
 class SCA61T {
     public:
-        SCA61T(PinName mosi, PinName miso, PinName sclk, PinName cbs, int device_sel);       
+        SCA61T(PinName mosi, PinName miso, PinName sclk, PinName csb, int device_sel);       
         ~SCA61T() {};
         
         /** Reads the angle
@@ -93,7 +93,7 @@
                 
     private:
         SPI SPI_m;
-        DigitalOut CBS_m;
+        DigitalOut CSB_m;
         
         void SPI_SendByte(uint8_t byte);
         uint8_t SPI_ReadReg(uint8_t reg);
@@ -33,7 +33,7 @@
 * #include "SCA61T.h"
 *
-* SCA61T sca61t(p11,p12,p13,p21,0);                  // MOSI, MISO, SCLK, CBS, device selection
+* SCA61T sca61t(p11,p12,p13,p21,0);                  // MOSI, MISO, SCLK, CSB, device selection
 *                                                    // 0=SCA61T-FAHH1G, 1=SCA61T-FA1H1G 
 * Serial pc(USBTX, USBRX);